# LiveKit Plugins PlayAI/PlayHT

Agent Framework plugin for voice synthesis with [PlayAI](https://play.ai/) API.

## Installation

```bash
pip install livekit-plugins-playai
```

## Pre-requisites

You'll need USER ID and API Secret KEY from PlayHT. It can be set as an environment variable: `PLAYHT_USER_ID`, `PLAYHT_API_KEY` get it from [here](https://play.ht/studio/api-access)
